@@ -1,10 +1,15 @@
 import os
+import PIL
 from PIL import ImageFont
 
 from viso_sdk.constants import FONTS_DIR
 from viso_sdk.logging import get_logger
 from viso_sdk.visualize.palette import get_rgba_color
 
+from packaging import version
+
+
+pil_version = PIL.__version__
 
 logger = get_logger("vis-font")
 
@@ -14,6 +19,20 @@ DEFAULT_TXT_COLOR = (255, 255, 255, 1.0)
 DEFAULT_SHADOW_COLOR = (0, 0, 0, 1.0)
 
 
+def get_text_size(draw, text, font, xy=(10, 10)):
+    # calculate area to put text
+    if version.parse(pil_version) < version.parse("10.0.0"):
+        text_width, text_height = draw.textsize(text, font)
+    else:
+        # Get the bounding box of the text
+        bbox = draw.textbbox(xy, text, font=font)
+
+        # Calculate the dimensions of the bounding box
+        text_width = bbox[2] - bbox[0]
+        text_height = bbox[3] - bbox[1]
+    return text_width, text_height
+
+
 def get_supported_fonts(fonts_dir=FONTS_DIR):
     font_names = [os.path.splitext(fn)[0] for fn in os.listdir(fonts_dir) if os.path.splitext(fn)[1] == '.ttf']
     return font_names
@@ -71,8 +90,7 @@ class VizTextDraw:
             fill_rectangle=False, fill_rectangle_color=None,
             show_shadow=False, shadow_color=None):
 
-        # calculate area to put text
-        text_width, text_height = draw.textsize(text, self.font)
+        text_width, text_height = get_text_size(draw=draw, text=text, font=self.font, xy=pos)
 
         padding = max(int(text_height // 4), 2)
         padding_left = padding
